###################################################
### chunk number 1: preliminaries
###################################################
options(width=70, useFancyQuotes = FALSE, prompt="R> ", continue="+  ")


###################################################
### chunk number 2: acopula-family
###################################################
require(nacopula)
ls("package:nacopula", pattern = "^cop[A-Z]")
copClayton
copClayton@psi
copClayton@psiInv # the inverse of psi(), psi^{-1}
copClayton@V0     # "sampler" for  V ~ F()


###################################################
### chunk number 3: ex1-definition
###################################################
(theta <- copJoe@tauInv(0.5))
C3joe.5 <- onacopula("Joe", C(theta, 1:3))


###################################################
### chunk number 4: ex1-str
###################################################
str(C3joe.5)  # str[ucture] of object


###################################################
### chunk number 5: ex1-splom
###################################################
require(lattice)
set.seed(1)
dim(U3 <- rnacopula(500, C3joe.5))
print(splom2(U3, cex = 0.4))


###################################################
### chunk number 6: ex1-explore1
###################################################
copJoe @ tau(theta)
round(cor(U3, method="kendall"), 3)


###################################################
### chunk number 7: ex1-explore2
###################################################
c(pnacopula(C3joe.5, c(.5, .5, .5)),
  pnacopula(C3joe.5, c(.99,.99,.99)))


###################################################
### chunk number 8: ex1-explore3
###################################################
prob(C3joe.5, c(.8, .8, .8), c(1, 1, 1))


###################################################
### chunk number 9: ex2-explore4
###################################################
c(copJoe @ lambdaL(theta),
  copJoe @ lambdaU(theta))


###################################################
### chunk number 10: NAC_3d-ex
###################################################
C3 <- onacopula("A", C(0.2, 1, C(0.8, 2:3)))
C3


###################################################
### chunk number 11: NAC_3d-ex2
###################################################
stopifnot(identical(C3,
      onacopula("A", C(0.2, 1, list(C(0.8, 2:3, list()))))
))


###################################################
### chunk number 12: AMH-V01
###################################################
copAMH @ nestConstr
copAMH @ V01


###################################################
### chunk number 13: ex2-definition
###################################################
theta0 <- copClayton@tauInv(0.2)
theta1 <- copClayton@tauInv(0.5)
theta2 <- copClayton@tauInv(0.8)
c(theta0, theta1, theta2)
C_9_clayton <- onacopula("Clayton",
                         C(theta0, c(3,6,1),
                           C(theta1, c(9,2,7,5),
                             C(theta2, c(8,4)))))
C_9_clayton


###################################################
### chunk number 14: ex2-splom
###################################################
set.seed(1)
dim(U9 <- rnacopula(500, C_9_clayton))
j <- allComp(C_9_clayton)
(vnames <- do.call(expression,
                   lapply(j, function(i) substitute( U[I], list(I=0+i)))))
print(splom2(U9[, j], varnames= vnames,
             cex = 0.4, pscales = 0))


###################################################
### chunk number 15: ex2-explore1
###################################################
round(cor(U9[,9],U9[,7], method="kendall"), 3)


###################################################
### chunk number 16: ex2-explore2
###################################################
c(pnacopula(C_9_clayton, rep(.5,9)),
  pnacopula(C_9_clayton, rep(.99,9)))


###################################################
### chunk number 17: ex2-explore3
###################################################
prob(C_9_clayton, rep(.8,9), rep(1,9))


###################################################
### chunk number 18: ex2-explore4
###################################################
c(copClayton @ lambdaL(theta0),
  copClayton @ lambdaU(theta0))
c(copClayton @ lambdaL(theta1),
  copClayton @ lambdaU(theta1))
c(copClayton @ lambdaL(theta2),
  copClayton @ lambdaU(theta2))


###################################################
### chunk number 19: outerpower-def
###################################################
str(opower)


###################################################
### chunk number 20: opwer-def2
###################################################
thetabase <- copClayton@tauInv(.5)
(opow.Clayton <- opower(copClayton, thetabase))


###################################################
### chunk number 21: opwer-def3
###################################################
theta0 <- opow.Clayton@tauInv(2/3) # will be 1.5
theta1 <- opow.Clayton@tauInv(.75) # will be 2
opC3 <- onacopula(opow.Clayton, C(theta0, 1, C(theta1, c(2,3))))


###################################################
### chunk number 22: opower-splom
###################################################
U3 <- rnacopula(500, opC3) ; stopifnot(dim(U3) == c(500,3))
print( splom2(U3, cex = 0.4) )


###################################################
### chunk number 23: opower-explore1
###################################################
round(cor(U3, method="kendall"), 3)


###################################################
### chunk number 24: opower-explore2
###################################################
rbind(th0 =
      c(L = opow.Clayton @ lambdaL(theta0),
        U = opow.Clayton @ lambdaU(theta0)),
      th1 =
      c(L = opow.Clayton @ lambdaL(theta1),
        U = opow.Clayton @ lambdaU(theta1)))


###################################################
### chunk number 25: sessionInfo
###################################################
toLatex(sessionInfo())


###################################################
### chunk number 26: nacopula-version eval=FALSE
###################################################
## my.strsplit(  packageDescription("nacopula")[["LastChanged"]]  )


###################################################
### chunk number 27: nacopula-version
###################################################
cat(strsplit(packageDescription("nacopula")[["LastChanged"]], "; *")[[1]],"", sep="\n")


